The main contributors are:

- `Pierre Augier <http://www.legi.grenoble-inp.fr/people/Pierre.Augier/>`_
  (LEGI, CNRS, UGA)

- `Ashwin Vishnu <https://github.com/ashwinvis>`_ (KTH, Stockholm)

- `Pierre Blanc-fatin <https://github.com/PierreBlancfat>`_ (UGA)

with ideas from `Serge Sans Paille <https://github.com/serge-sans-paille/>`_
and `Wolf Vollprecht <https://twitter.com/wuoulf>`_.

Of course Transonic could not exist without Serge, a benefactor to humankind
who brings efficiency for numerical computing to snake tamers. Trugarez for his
great work on Pythran and Beniget!

A very special thanks to `Laura Mendoza <https://github.com/lasofivec>`_ who
replaced Pierre Augier to give our presentation at `Pyconfr 2019
<https://www.pycon.fr/2019/>`_.
